package VMOMI::GuestOsDescriptorFirmwareType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
